from distutils.core import setup

setup( 
        name         = 'nesterDean', 
        version      = '1.0.1', 
        ## TODO: be sure to change these next few lines to match your details!
        py_modules   = ['nesterDean'],
        author       = 'dean',
        author_email = 'dean@headfirstlabs.com',
        url          = 'http://www.headfirstlabs.com',
        description  = 'A simple printer of nested lists',
     )
